summaryrefslogtreecommitdiffstats
path: root/net/http/http_transaction.h
diff options
context:
space:
mode:
authoragl@chromium.org <agl@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-10-12 17:22:45 +0000
committeragl@chromium.org <agl@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-10-12 17:22:45 +0000
commitafc26521e0f0b4960337eb3473c1529a6fb407af (patch)
treec5f8760aceae670a6d0a1fd4b2f40ca8f02547d5 /net/http/http_transaction.h
parent66c51f716433a3bf9fb0a5547919df61f040f7cd (diff)
downloadchromium_src-afc26521e0f0b4960337eb3473c1529a6fb407af.zip
chromium_src-afc26521e0f0b4960337eb3473c1529a6fb407af.tar.gz
chromium_src-afc26521e0f0b4960337eb3473c1529a6fb407af.tar.bz2
Rename SSLNonSensitiveHostInfo to SSLHostInfo.
No effective code change. BUG=none TEST=net_unittests Review URL: http://codereview.chromium.org/3728002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@62295 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/http/http_transaction.h')
-rw-r--r--net/http/http_transaction.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/net/http/http_transaction.h b/net/http/http_transaction.h
index 2fcd245..1923851 100644
--- a/net/http/http_transaction.h
+++ b/net/http/http_transaction.h
@@ -17,7 +17,7 @@ struct HttpRequestInfo;
class HttpResponseInfo;
class IOBuffer;
class X509Certificate;
-class SSLNonSensitiveHostInfo;
+class SSLHostInfo;
// Represents a single HTTP transaction (i.e., a single request/response pair).
// HTTP redirects are not followed and authentication challenges are not
@@ -106,10 +106,10 @@ class HttpTransaction {
// zero will be returned. This does not include the request headers.
virtual uint64 GetUploadProgress() const = 0;
// SetSSLNonSensitiveHostInfo sets a object which reads and writes public
// information about an SSL server. It's used to implement Snap Start.
// TODO(agl): remove this.
- virtual void SetSSLNonSensitiveHostInfo(SSLNonSensitiveHostInfo*) { };
+ virtual void SetSSLHostInfo(SSLHostInfo*) { };
};
} // namespace net
@@ -106,10 +106,10 @@ class HttpTransaction {
// zero will be returned. This does not include the request headers.
virtual uint64 GetUploadProgress() const = 0;
- // SetSSLNonSensitiveHostInfo sets a object which reads and writes public
- // information about an SSL server. It's used to implement Snap Start.
+ // SetSSLHostInfo sets a object which reads and writes public information
+ // about an SSL server. It's used to implement Snap Start.
// TODO(agl): remove this.